import { Component, ElementRef, OnInit, Renderer2, ViewEncapsulation } from '@angular/core';
import { DomSanitizer, Meta, Title } from '@angular/platform-browser';
import { ActivatedRoute } from '@angular/router';
import { RouterListenerService } from '../../../services/routerListener.service';
import { Post } from '../../models/post.model';
import { PostService } from '../../services/post.service';

@Component({
  selector: 'app-post-details',
  templateUrl: './post-details.component.html',
  styleUrls: ['./post-details.component.scss', '../../../../assets/ghost/cards.min.css'],
  encapsulation: ViewEncapsulation.None,
})
export class PostDetailsComponent implements OnInit {
  public post: Post;

  constructor(
    private activatedRoute: ActivatedRoute,
    private postService: PostService,
    private sanitizer: DomSanitizer,
    private routerListener: RouterListenerService,
    private readonly elementRef: ElementRef,
    private renderer: Renderer2,
    private title: Title,
    private meta: Meta,
  ) {}

  ngOnInit(): void {
    if (history.state.data) {
      this.post = new Post(history.state.data);
      this.post.safeHtml = this.sanitizer.bypassSecurityTrustHtml(this.post.html);
    } else {
      const postSlug = this.activatedRoute.snapshot.paramMap.get('slug');
      this.postService.getPost(postSlug).subscribe((post) => {
        this.post = post.posts[0];
        this.post.safeHtml = this.sanitizer.bypassSecurityTrustHtml(this.post.html);

        this.meta.addTag({ property: 'og:title', content: this.post.title });
        // this.meta.addTag({ property: 'og:image', content: this.post.feature_image });
        this.meta.addTag({
          property: 'og:image',
          content: 'https://resin-dev.apps.grandlyon.com/assets/logos/logo_europe.png',
        });
      });
    }
    // add ghost JS
    const script = this.renderer.createElement('script');
    script.src = '/assets/ghost/cards.min.js';
    this.renderer.appendChild(this.elementRef.nativeElement, script);
    // set page title
    this.title.setTitle(this.post.title + " | Réseau des acteurs de l'inclusion numérique de la métropole de Lyon");

    this.meta.updateTag({ property: 'og:title', content: this.post.title });
    this.meta.updateTag({ property: 'og:image', content: this.post.feature_image });
  }

  public backToPosts(): void {
    this.routerListener.goToPreviousUrl();
  }
}
